@@ -12,7 +12,7 @@
  *
  * Also finds out IP of specified MAC
  *
- * $Id: arping.c,v 1.13 2000/05/22 20:46:42 marvin Exp $
+ * $Id: arping.c,v 1.16 2000/07/02 11:05:56 marvin Exp $
  */
 /*
  *  Copyright (C) 2000 Marvin (marvin@nss.nu)
@@ -37,7 +37,7 @@
 #include <net/if.h>
 #include <net/if_arp.h>
 
-const float version = 0.5;
+const float version = 0.6;
 
 struct ether_addr *mymac;
 u_char eth_xmas[ETH_ALEN] = {0xff, 0xff, 0xff, 0xff, 0xff, 0xff};
@@ -62,13 +62,14 @@ unsigned int searchmac = 0;
 unsigned int finddup = 0;
 unsigned int maxcount = -1;
 unsigned int rawoutput = 0;
+unsigned int nullip = 0;
 
 void sigint(int i);
 
 
 void usage(int ret)
 {
-	printf("arping %1.1f [ -v ] [ -r ] [ -d ] [ -c count ] "
+	printf("arping %1.1f [ -v ] [ -r ] [ -d ] [-0 ] [ -c count ] "
 	       "[ -i <interface> ] <host/ip/MAC>\n", version);
 	exit(ret);
 }
@@ -83,7 +84,7 @@ void alasend(int i)
 		libnet_build_icmp_echo(ICMP_ECHO,      /* type */ 
 				       0,              /* code */ 
 				       4321,           /* id */ 
-				       htons(numsent), /* seq */ 
+				       htons(numsent-1), /* seq */ 
 				       NULL,           /* pointer to payload */
 				       0,              /* payload length */ 
 				       /* header memory */ 
@@ -183,7 +184,6 @@ void handlepacket(const char *unused, struct pcap_pkthdr *h, u_char *packet)
 					      + sizeof(struct arphdr)
 					      + harp->ar_hln);
 			if (dip == ip) {
-				numrecvd;
 				cp = (u_char*)harp + sizeof(struct arphdr);
 				if (!rawoutput && !finddup) {
 					printf("%d bytes from ", h->len);
@@ -198,7 +198,7 @@ void handlepacket(const char *unused, struct pcap_pkthdr *h, u_char *packet)
 					       numrecvd++);
 				}
 				printf("\n");
-				}
+			}
 		}
 	}
 
@@ -219,7 +219,7 @@ int main(int argc, char **argv)
 	int c;
 	struct bpf_program bp;
 	
-	while ((c = getopt(argc, argv, "dvhi:rc:")) != EOF) {
+	while ((c = getopt(argc, argv, "0dvhi:rc:")) != EOF) {
 		switch (c) {
 		case 'v':
 			verbose++;
@@ -227,6 +227,13 @@ int main(int argc, char **argv)
 		case 'h':
 			usage(0);
 		case 'i':
+			if (strchr(optarg, ':')) {
+				fprintf(stderr, "arping: If you're trying to "
+					"feed me an interface alias then you "
+					"don't really\nknow what this programs"
+					" does, do you?\n");
+				exit(1);
+			}
 			ifname = optarg;
 			break;
 		case 'r':
@@ -238,6 +245,9 @@ int main(int argc, char **argv)
 		case 'd':
 			finddup = 1;
 			break;
+		case '0':
+			nullip = 1;
+			break;
 		default:
 			usage(1);
 		}
@@ -290,7 +300,10 @@ int main(int argc, char **argv)
 		exit(1);
 	}
 	
-	if (!(myip = htonl(libnet_get_ipaddr(linkint,(u_char*)ifname,ebuf)))) {
+	if (nullip) {
+		myip = 0;
+	} else if  (!(myip = htonl(libnet_get_ipaddr(linkint,(u_char*)ifname,
+						     ebuf)))) {
 		fprintf(stderr, "libnet_get_ipaddr(): %s\n", ebuf);
 		exit(1);
 	}
